==> kubernetes-model-1.0.29-sources.jar: io/fabric8/kubernetes/api/model/NamespaceSpecFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.util.ArrayList;
import java.util.Map;
import java.util.HashMap;
import java.util.List;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;

public class NamespaceSpecFluentImpl<T extends NamespaceSpecFluent<T>> extends BaseFluent<T> implements NamespaceSpecFluent<T>{

     List<String> finalizers = new ArrayList();     Map<String, Object> additionalProperties = new HashMap();

    public T addToFinalizers( String ...items){
    for (String item : items) {this.finalizers.add(item);} return (T)this;
    }
    public T removeFromFinalizers( String ...items){
    for (String item : items) {this.finalizers.remove(item);} return (T)this;
    }
    public List<String> getFinalizers(){
    return this.finalizers;
    }
    public T withFinalizers( List<String> finalizers){
    this.finalizers.clear();if (finalizers != null) {for (String item : finalizers){this.addToFinalizers(item);}} return (T) this;
    }
    public T withFinalizers( String ...finalizers){
    this.finalizers.clear(); if (finalizers != null) {for (String item :finalizers){ this.addToFinalizers(item);}} return (T) this;
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
NamespaceSpecFluentImpl that = (NamespaceSpecFluentImpl) o;
if (finalizers != null ? !finalizers.equals(that.finalizers) :that.finalizers != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }



}

==> kubernetes-model-1.0.31-sources.jar: io/fabric8/kubernetes/api/model/NamespaceSpecFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.util.ArrayList;
import java.util.Map;
import java.util.HashMap;
import java.util.List;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;

public class NamespaceSpecFluentImpl<T extends NamespaceSpecFluent<T>> extends BaseFluent<T> implements NamespaceSpecFluent<T>{

     List<String> finalizers = new ArrayList();     Map<String, Object> additionalProperties = new HashMap();

    public T addToFinalizers( String ...items){
    for (String item : items) {this.finalizers.add(item);} return (T)this;
    }
    public T removeFromFinalizers( String ...items){
    for (String item : items) {this.finalizers.remove(item);} return (T)this;
    }
    public List<String> getFinalizers(){
    return this.finalizers;
    }
    public T withFinalizers( List<String> finalizers){
    this.finalizers.clear();if (finalizers != null) {for (String item : finalizers){this.addToFinalizers(item);}} return (T) this;
    }
    public T withFinalizers( String ...finalizers){
    this.finalizers.clear(); if (finalizers != null) {for (String item :finalizers){ this.addToFinalizers(item);}} return (T) this;
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T addToAdditionalProperties( Map<String, Object> map){
    if(map != null) { this.additionalProperties.putAll(map);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public T removeFromAdditionalProperties( Map<String, Object> map){
    if(map != null) { for(Object key : map.keySet()) {this.additionalProperties.remove(key);}} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
NamespaceSpecFluentImpl that = (NamespaceSpecFluentImpl) o;
if (finalizers != null ? !finalizers.equals(that.finalizers) :that.finalizers != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }



}
